
======
Python
======

Crawler
=======

* `Beautiful Soup <https://www.crummy.com/software/BeautifulSoup/bs4/doc/>`_, Beautiful Soup
  is a Python library for pulling data out of HTML and XML files. It works with your favorite parser to
  provide idiomatic ways of navigating, searching, and modifying the parse tree. It commonly saves
  programmers hours or days of work. These instructions illustrate all major features of Beautiful Soup 4,
  with examples. I show you what the library is good for, how it works, how to use it, how to make it do
  what you want, and what to do when it violates your expectations.



